@@ -29,7 +29,7 @@ class Vn:
         #----------------------------------------------------------------
         # Load Network API Json
         self.network_api_json: dict = None
-        with open(os.path.join(sys.path[0], 'network_api_v25.json'), encoding="utf-8") as file:
+        with open('network_api_v25.json', encoding="utf-8") as file:
             self.network_api_json = json.load(file)
         self.network_api_parsed: dict = self.__parse_network_api_json(self.network_api_json)
 
